"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.choosePort = choosePort;
exports.default = void 0;

var _detectPortAlt = _interopRequireDefault(require("detect-port-alt"));

var _isRoot = _interopRequireDefault(require("is-root"));

var _prompts = _interopRequireDefault(require("prompts"));

var _chalk = _interopRequireDefault(require("chalk"));

var logger = _interopRequireWildcard(require("../../../utils/logger"));

var _memoize = _interopRequireDefault(require("../../../utils/memoize"));

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const isInteractive = process.stdout.isTTY;

async function choosePort(host, defaultPort) {
  const port = await (0, _detectPortAlt.default)(defaultPort, host);

  if (port === defaultPort) {
    return port;
  }

  const message = process.platform !== 'win32' && defaultPort < 1024 && !(0, _isRoot.default)() ? `Admin permissions are required to run a server on a port below 1024.` : `Something is already running on port ${defaultPort}.`;

  if (isInteractive) {
    logger.clear();
    const answer = await (0, _prompts.default)({
      type: 'confirm',
      name: 'shouldChangePort',
      message: _chalk.default.yellow(message + '\n\nWould you like to run the app on another port instead?')
    });

    if (answer.shouldChangePort) {
      return port;
    } else {
      return undefined;
    }
  } else {
    logger.error(message);
  }
}

const getPort = async host => {
  const port = await choosePort(host, parseInt(process.env.PORT || '3000', 0));

  if (port) {
    return port;
  } else {
    throw new Error(`Could not identify port to run against`);
  }
};

var _default = (0, _memoize.default)(getPort);

exports.default = _default;
//# sourceMappingURL=getPort.js.map