#!/usr/bin/env node
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.program = void 0;

var fs = _interopRequireWildcard(require("fs-extra"));

var _isCi = _interopRequireDefault(require("is-ci"));

var _chalk = _interopRequireDefault(require("chalk"));

var _commander = _interopRequireWildcard(require("commander"));

var _actionPreflightCheck = _interopRequireDefault(require("./utils/actionPreflightCheck"));

var logger = _interopRequireWildcard(require("./utils/logger"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const program = new _commander.default.Command('modular');
exports.program = program;
program.version(fs.readJsonSync(require.resolve('modular-scripts/package.json')).version);
program.command('add').description(`Add a new package into the modular workspace.`).argument('[package-name]', 'Package name for the package.json').option('--unstable-type <type>', "Type of the package ('app', 'view', 'package')").option('--unstable-name <name>', 'Package name for the package.json').option('--template <name>', 'Template name').option('--prefer-offline', 'Equivalent of --prefer-offline for yarn installations', true).option('--verbose', 'Run yarn commands with --verbose set').action(async (packageName, addOptions) => {
  const {
    default: addPackage
  } = await Promise.resolve().then(() => _interopRequireWildcard(require('./addPackage')));
  return addPackage({
    name: packageName,
    type: addOptions.unstableType,
    template: addOptions.template,
    preferOffline: addOptions.preferOffline,
    verbose: addOptions.verbose,
    unstableName: addOptions.unstableName
  });
});
program.command('analyze <package-name>').description(`Analyze the dependencies of a package.`).action(async packageName => {
  const {
    default: analyze
  } = await Promise.resolve().then(() => _interopRequireWildcard(require('./analyze')));
  return analyze({
    target: packageName
  });
});
program.command('build <packages...>').description('Build a list of packages (multiple package names can be supplied separated by space)').option('--preserve-modules [value]', 'Preserve module structure in generated modules', 'true').option('--verbose', 'Run yarn commands with --verbose set').option('--private', 'Enable the building of private packages', false).action(async (packagePaths, options) => {
  const {
    default: build
  } = await Promise.resolve().then(() => _interopRequireWildcard(require('./build')));
  logger.log('building packages at:', packagePaths.join(', '));

  for (let i = 0; i < packagePaths.length; i++) {
    try {
      await build(packagePaths[i], JSON.parse(options.preserveModules), options.private);
    } catch (err) {
      logger.error(`building ${packagePaths[i]} failed`);
      throw err;
    }
  }
});

const testOptions = // eslint-disable-next-line @typescript-eslint/no-var-requires
require('jest-cli/build/cli/args.js').options;

program.command('test [regexes...]').option('--ancestors', 'Additionally run tests for workspaces that depend on workspaces that have changed', false).option('--debug', 'Setup node.js debugger on the test process - equivalent of setting --inspect-brk on a node.js process', false).option('--changed', 'Run tests only for workspaces that have changed compared to the branch specified in --compareBranch').option('--compareBranch <branch>', "Specifies the branch to use with the --changed flag. If not specified, Modular will use the repo's default branch").option('--coverage', testOptions.coverage.description).option('--forceExit', testOptions.forceExit.description).option('--env <env>', testOptions.env.description, 'jsdom').option('--maxWorkers <workers>', testOptions.maxWorkers.description).option('--onlyChanged', testOptions.onlyChanged.description).option('--json', testOptions.json.description).option('--outputFile <file>', testOptions.outputFile.description).option('--reporters <reporters...>', testOptions.reporters.description).option('--runInBand', testOptions.runInBand.description).option('--silent', testOptions.silent.description).option('--showConfig', testOptions.showConfig.description).option('--testResultsProcessor <reporter>', testOptions.testResultsProcessor.description).option('--updateSnapshot, -u', testOptions.updateSnapshot.description).option('--verbose', testOptions.verbose.description).option('--watch', testOptions.watch.description).option('--watchAll [value]', testOptions.watchAll.description, !_isCi.default).option('--bail [value]', testOptions.bail.description, _isCi.default).option('--clearCache', testOptions.clearCache.description).option('--logHeapUsage', testOptions.logHeapUsage.description).option('--no-cache', testOptions.cache.description).allowUnknownOption().description('Run tests over the codebase').action(async (regexes, options) => {
  if (options.ancestors && !options.changed) {
    process.stderr.write("Option --ancestors doesn't make sense without option --changed");
    process.exit(1);
  }

  if (options.compareBranch && !options.changed) {
    process.stderr.write("Option --compareBranch doesn't make sense without option --changed");
    process.exit(1);
  }

  if (options.changed && regexes.length) {
    process.stderr.write('Option --changed conflicts with supplied test regex');
    process.exit(1);
  }

  const {
    default: test
  } = await Promise.resolve().then(() => _interopRequireWildcard(require('./test'))); // proxy simplified options to testOptions

  const {
    U,
    ...testOptions
  } = options;
  testOptions.updateSnapshot = !!(options.updateSnapshot || U);
  return test(testOptions, regexes);
});
program.command('start [packageName]').description(`Start a dev-server for an app. Only available for modular 'app' types.`).option('--verbose', 'Run yarn commands with --verbose set').action(async packageName => {
  const {
    default: start
  } = await Promise.resolve().then(() => _interopRequireWildcard(require('./start')));
  return start(packageName);
});
program.command('workspace').description('Retrieve the information for the current workspace info').action((0, _actionPreflightCheck.default)(async () => {
  const {
    default: getWorkspaceInfo
  } = await Promise.resolve().then(() => _interopRequireWildcard(require('./utils/getWorkspaceInfo')));
  const workspace = await getWorkspaceInfo();
  process.stdout.write(JSON.stringify(workspace, null, 2));
}));
program.command('init').description('Initialize a new modular root in the current folder').option('-y', 'equivalent to the -y flag in NPM').option('--prefer-offline [value]', 'delegate to offline cache first', true).option('--verbose', 'Run yarn commands with --verbose set').action(async options => {
  const {
    default: initWorkspace
  } = await Promise.resolve().then(() => _interopRequireWildcard(require('./init')));
  await initWorkspace(options.y, JSON.parse(options.preferOffline), options.verbose);
});
program.command('check').description('Manually run modular checks against the current modular repository').option('--fix', 'Run autofixers which are available.').option('--verbose', 'Run yarn commands with --verbose set').action(async ({
  fix
}) => {
  const {
    check
  } = await Promise.resolve().then(() => _interopRequireWildcard(require('./check')));
  await check({
    fix
  });
  logger.log(_chalk.default.green('Success!'));
});
program.command('convert').description('Converts react app in current directory into a modular package').action(async () => {
  const {
    convert
  } = await Promise.resolve().then(() => _interopRequireWildcard(require('./convert')));
  await convert();
  logger.log(_chalk.default.green('Successfully converted your app into a modular app!'));
}); // TODO: enhancement - should take a type option (app, view, package)
// port are only available for apps right now

program.command('port <relativePath>').description('Ports the react app in specified directory over into the current modular project as a modular app').action(async relativePath => {
  const {
    port
  } = await Promise.resolve().then(() => _interopRequireWildcard(require('./port')));
  await port(relativePath);
});
const lintStagedFlag = '--staged';
program.command('lint [regexes...]').option('--all', 'Only lint diffed files from your remote origin default branch (e.g. main or master)').option('--fix', `Fix the lint errors wherever possible, restages changes if run with ${lintStagedFlag}`).addOption(new _commander.Option(lintStagedFlag, 'Only lint files that have been staged to be committed').conflicts('all')).description('Lints the codebase').action(async (regexes, options) => {
  const {
    default: lint
  } = await Promise.resolve().then(() => _interopRequireWildcard(require('./lint')));
  await lint(options, regexes);
});
program.command('typecheck').description('Typechecks the entire project').option('--verbose', 'Enables verbose logging within modular.').action(async () => {
  const {
    default: typecheck
  } = await Promise.resolve().then(() => _interopRequireWildcard(require('./typecheck')));
  await typecheck();
});
program.command('rename <oldPackageName> <newPackageName>').description(`Rename a package.`).option('--verbose', 'Enables verbose logging within modular.').action(async (oldPackageName, newPackageName) => {
  const {
    default: rename
  } = await Promise.resolve().then(() => _interopRequireWildcard(require('./rename')));
  await rename(oldPackageName, newPackageName);
});
program.command('serve <target>').description('Serves a pre-built modular app').option('--port <value>', 'Port to serve on', '3000').action(async (packageName, options) => {
  const {
    default: serve
  } = await Promise.resolve().then(() => _interopRequireWildcard(require('./serve')));
  await serve(packageName, parseInt(options.port, 10));
});
//# sourceMappingURL=program.js.map