"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _tsMorph = require("ts-morph");

var _execa = _interopRequireDefault(require("execa"));

var _actionPreflightCheck = _interopRequireDefault(require("./utils/actionPreflightCheck"));

var _getModularRoot = _interopRequireDefault(require("./utils/getModularRoot"));

var _getWorkspaceInfo = _interopRequireDefault(require("./utils/getWorkspaceInfo"));

var fs = _interopRequireWildcard(require("fs-extra"));

var path = _interopRequireWildcard(require("path"));

var logger = _interopRequireWildcard(require("./utils/logger"));

var _gitActions = require("./utils/gitActions");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

process.on('SIGINT', () => {
  (0, _gitActions.stashChanges)();
  process.exit(1);
});

async function rename(oldPackageName, newPackageName) {
  const workspace = await (0, _getWorkspaceInfo.default)();
  logger.debug(`Checking for existence of ${oldPackageName} in workspace.`);
  const workspacePackage = workspace[oldPackageName];

  if (!workspacePackage) {
    throw new Error(`Package ${oldPackageName} not found.`);
  }

  logger.debug(`Checking for collision with ${newPackageName} in workspace.`);

  if (workspace[newPackageName]) {
    throw new Error(`Package ${newPackageName} already exists.`);
  }

  if (!(0, _gitActions.cleanGit)(process.cwd())) {
    throw new Error('You have unsaved changes. Please save or stash them before we attempt to rename a package.');
  }

  try {
    const packageJsonLocation = path.join(workspacePackage.location, './package.json');
    const packageJson = await fs.readJson(packageJsonLocation);
    logger.log(`Changing package name ${packageJson.name} → ${newPackageName}`);
    packageJson.name = newPackageName;
    await fs.writeJson(packageJsonLocation, packageJson, {
      spaces: 2
    });
    logger.log(`Rewriting imports in source files`);
    await Promise.all(Object.values(workspace).map(async packageData => {
      const project = new _tsMorph.Project();
      project.addSourceFilesAtPaths(path.join((0, _getModularRoot.default)(), packageData.location, 'src/**/*{.d.ts,.ts,.js,.jsx,.tsx}'));
      const sourceFiles = project.getSourceFiles();
      sourceFiles.forEach(sourceFile => {
        const imports = sourceFile.getImportDeclarations();
        imports.forEach(importDeclaration => {
          if (importDeclaration.getModuleSpecifierValue() === oldPackageName) {
            logger.debug(`Rewriting \`${importDeclaration.getText()}\` in ${sourceFile.getFilePath()}`);
            importDeclaration.setModuleSpecifier(newPackageName);
          }
        });
      });
      await project.save();
    }));
    logger.log(`Refreshing packages`);

    _execa.default.sync('yarnpkg', ['--silent'], {
      cwd: (0, _getModularRoot.default)()
    });
  } catch (err) {
    logger.error(err);
    (0, _gitActions.stashChanges)();
  }
}

var _default = (0, _actionPreflightCheck.default)(rename);

exports.default = _default;
//# sourceMappingURL=rename.js.map