"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _stream = require("stream");

class LineFilterOutStream extends _stream.Transform {
  // A stream transform to filter out lines that pass the regexp test
  buffer = '';

  constructor(pattern) {
    super();
    this.pattern = pattern;
  }

  _transform(chunk, encoding, callback) {
    const data = String(chunk);
    const lines = data.split('\n'); // Handle last line which is probably incomplete

    lines[0] = this.buffer + lines[0];
    this.buffer = lines.pop() ?? '';
    const output = lines.reduce((acc, line) => {
      if (!this.pattern.test(line)) {
        acc += `${line}\n`;
      }

      return acc;
    }, '');
    this.push(output);
    callback();
  }

}

exports.default = LineFilterOutStream;
//# sourceMappingURL=LineFilterOutStream.js.map