"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var path = _interopRequireWildcard(require("path"));

var ts = _interopRequireWildcard(require("typescript"));

var fse = _interopRequireWildcard(require("fs-extra"));

var _memoize = _interopRequireDefault(require("../utils/memoize"));

var _getModularRoot = _interopRequireDefault(require("../utils/getModularRoot"));

var _getAllWorkspaces = require("../utils/getAllWorkspaces");

var _reportTSDiagnostics = require("./reportTSDiagnostics");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const typescriptConfigFilename = 'tsconfig.json';

function distinct(arr) {
  return [...new Set(arr)];
}

async function getPackageMetadata() {
  const modularRoot = (0, _getModularRoot.default)(); // dependencies defined at the root

  const rootPackageJsonDependencies = fse.readJSONSync(path.join(modularRoot, 'package.json')).dependencies || {}; // let's populate the above three

  const [workspaces] = await (0, _getAllWorkspaces.getAllWorkspaces)(); // an array of all the package names

  const packageNames = Array.from(workspaces.keys()); // a map of all package.json contents, indexed by package name

  const packageJsons = {};
  const packageJsonsByPackagePath = {};
  Array.from(workspaces).forEach(([packageName, workspace]) => {
    packageJsons[packageName] = workspace.rawPackageJson;
    packageJsonsByPackagePath[workspace.location] = workspace.rawPackageJson;
  }); // TODO: do a quick check to make sure workspaces aren't
  // explicitly included in dependencies
  // maybe that belongs in `modular check`

  const typescriptConfig = {}; // validate tsconfig
  // Extract configuration from config file and parse JSON,
  // after removing comments. Just a fancier JSON.parse

  const result = ts.parseConfigFileTextToJson(path.join(modularRoot, typescriptConfigFilename), fse.readFileSync(typescriptConfigFilename, 'utf8').toString());
  const configObject = result.config;

  if (!configObject) {
    (0, _reportTSDiagnostics.reportTSDiagnostics)(':root', [result.error]);
    throw new Error('Failed to load Typescript configuration');
  }

  Object.assign(typescriptConfig, configObject, {
    // TODO: should probably include the original exclude in this
    exclude: distinct([// all TS test files, regardless whether co-located or in test/ etc
    '**/*.stories.ts', '**/*.stories.tsx', '**/*.spec.ts', '**/*.test.ts', '**/*.e2e.ts', '**/*.spec.tsx', '**/*.test.tsx', '**/__tests__', '**/dist-cjs', '**/dist-es', '**/dist-types', // TS defaults below
    'node_modules', 'bower_components', 'jspm_packages', 'tmp', // Casting so that configObject.exclude is set to the correct typing
    // Since configObject is a index type all values are "any" implicitly.
    ...(configObject.exclude || [])])
  });
  typescriptConfig.compilerOptions = typescriptConfig.compilerOptions || {};
  Object.assign(typescriptConfig.compilerOptions, {
    noEmit: false,
    declaration: true,
    emitDeclarationOnly: true,
    incremental: false
  });
  return {
    packageNames,
    rootPackageJsonDependencies,
    packageJsons,
    typescriptConfig,
    packageJsonsByPackagePath
  };
}

var _default = (0, _memoize.default)(getPackageMetadata);

exports.default = _default;
//# sourceMappingURL=getPackageMetadata.js.map