"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
exports.getWorkspaceInfo = getWorkspaceInfo;

var _getAllWorkspaces = require("./getAllWorkspaces");

var _memoize = _interopRequireDefault(require("./memoize"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

async function getWorkspaceInfo(target) {
  const [workspaces, workspacesMap] = await (0, _getAllWorkspaces.getAllWorkspaces)(target);
  const workspaceInfo = {};
  return Object.entries(workspacesMap).reduce((byPath, [packageName, packageInfo]) => {
    var _rawPackageJson$modul;

    const workspace = workspaces.get(packageName); // @modular-scripts/workspace-resolver should guarantee a 1:1 relationship of items in workspaces and workspacesMap

    if (!workspace) {
      throw new Error('Modular was not able to understand your workspaces configuration');
    }

    const {
      rawPackageJson
    } = workspace;
    const type = ((_rawPackageJson$modul = rawPackageJson.modular) === null || _rawPackageJson$modul === void 0 ? void 0 : _rawPackageJson$modul.type) || 'package';
    workspaceInfo[packageName] = { ...packageInfo,
      type,
      public: !rawPackageJson.private,
      version: rawPackageJson.version
    };
    return byPath;
  }, workspaceInfo);
}

var _default = (0, _memoize.default)(getWorkspaceInfo);

exports.default = _default;
//# sourceMappingURL=getWorkspaceInfo.js.map